##  Monitoring the Usage and Adoption of SAP LeanIX
As a workspace admin, you can monitor how your organization uses SAP LeanIX and identify possible improvements. You can request access to a Shared 360 view powered by Gainsight where you can track various usage and adoption metrics. For more information, see [Monitoring the Usage and Adoption of SAP LeanIX](https://help.sap.com/docs/leanix/ea/monitor-usage-and-adoption?locale=en-US&state=PRODUCTION&version=CLOUD "Monitor how your organization uses SAP LeanIX by tracking key metrics in a Shared 360 view powered by Gainsight.").
YesNo
Send
